@@ -24,9 +24,8 @@ class NoneX(Transform):
         if value is not None:
             raise TypeError("value must be 'None'")
 
-    @classmethod
     def __unpack__(
-        cls, buffer: bytes, offset: int, dump: Optional[Record] = None
+        self, buffer: bytes, offset: int, dump: Optional[Record] = None
     ) -> Tuple[None, int]:
         if dump is not None:
             dump.value = "None"
